==> haskell-cereal-0.5.7.0-1-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cereal
version: 0.5.7.0
id: cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
key: cereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
license: BSD-3-Clause
maintainer: Trevor Elliott <trevor@galois.com>
author: Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
        Galois Inc.,
        Lemmih <lemmih@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: provisional
homepage: https://github.com/GaloisInc/cereal
synopsis: A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.
category: Data, Parsing
abi: 91a5befe140ca1e57734aef5b9be7102
exposed: True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put
import-dirs: /usr/lib/ghc-8.4.3/site-local/cereal-0.5.7.0
library-dirs: /usr/lib/ghc-8.4.3/site-local/cereal-0.5.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.4.3/cereal-0.5.7.0
hs-libraries: HScereal-0.5.7.0-GeNBgd8Wa452X4EoKnwsnC
depends:
    base-4.11.1.0 containers-0.5.11.0 array-0.5.2.0 ghc-prim-0.5.2.0
    bytestring-0.10.8.2
abi-depends: base-4.11.1.0=9da3f387598d41928f3ebf8097acf9b3
             containers-0.5.11.0=7795138514357bd2e41eaf59b6cfce4f
             array-0.5.2.0=001d57bac323829c35f5e9edd158c1ef
             ghc-prim-0.5.2.0=39dc2488936298f474639901f9105eec
             bytestring-0.10.8.2=76943c00398d547fb172e56c2f93c635
haddock-interfaces: /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html: /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-cereal-0.5.7.0-2-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-cereal.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: cereal
version: 0.5.7.0
id: cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
key: cereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
license: BSD-3-Clause
maintainer: Trevor Elliott <trevor@galois.com>
author: Lennart Kolmodin <kolmodin@dtek.chalmers.se>,
        Galois Inc.,
        Lemmih <lemmih@gmail.com>,
        Bas van Dijk <v.dijk.bas@gmail.com>
stability: provisional
homepage: https://github.com/GaloisInc/cereal
synopsis: A binary serialization library
description:
    A binary serialization library, similar to binary, that introduces an isolate
    primitive for parser isolation, and labeled blocks for better error messages.
category: Data, Parsing
abi: fb55ac191a51583cb2e3abbb48e2ad21
exposed: True
exposed-modules:
    Data.Serialize Data.Serialize.Get Data.Serialize.IEEE754
    Data.Serialize.Put
import-dirs: /usr/lib/ghc-8.6.1/site-local/cereal-0.5.7.0
library-dirs: /usr/lib/ghc-8.6.1/site-local/cereal-0.5.7.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.1/cereal-0.5.7.0
hs-libraries: HScereal-0.5.7.0-2uER3Agem8P6aYfM1x47n8
depends:
    array-0.5.2.0 base-4.12.0.0 bytestring-0.10.8.2 containers-0.6.0.1
    ghc-prim-0.5.3
haddock-interfaces: /usr/share/doc/haskell-cereal/html/cereal.haddock
haddock-html: /usr/share/doc/haskell-cereal/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
